Code of Conduct
---------------

We want everyone in the community of users and contributors to PyDeseq2 to feel welcomed.

`PyDeseq2` follows the code of conduct defined by
the Python Software Foundation: https://www.python.org/psf/codeofconduct/.
